@@ -21,6 +21,9 @@ class WarningsFixture(fixtures.Fixture):
 
     def setUp(self):
         super().setUp()
+
+        self._original_warning_filters = warnings.filters[:]
+
         # Make deprecation warnings only happen once to avoid spamming
         warnings.simplefilter('once', DeprecationWarning)
 
@@ -42,21 +45,6 @@ class WarningsFixture(fixtures.Fixture):
             message=r'The Session.autocommit parameter is deprecated .*',
             category=sqla_exc.SADeprecationWarning)
 
-        warnings.filterwarnings(
-            'once',
-            message=r'The Session.begin.subtransactions flag is deprecated .*',
-            category=sqla_exc.SADeprecationWarning)
-
-        warnings.filterwarnings(
-            'once',
-            message=r'The current statement is being autocommitted .*',
-            category=sqla_exc.SADeprecationWarning)
-
-        warnings.filterwarnings(
-            'once',
-            message=r'Calling \.begin\(\) when a transaction is already .*',
-            category=sqla_exc.SADeprecationWarning)
-
         # ...plus things that aren't our fault
 
         # FIXME(stephenfin): These are caused by sqlalchemy-migrate, not us,
@@ -68,10 +56,19 @@ class WarningsFixture(fixtures.Fixture):
             module='migrate',
             category=sqla_exc.SADeprecationWarning)
 
+        warnings.filterwarnings(
+            'once',
+            message=r'The current statement is being autocommitted .*',
+            module='migrate',
+            category=sqla_exc.SADeprecationWarning)
+
         warnings.filterwarnings(
             'ignore',
             message=r'The Engine.execute\(\) method is considered legacy .*',
             module='migrate',
             category=sqla_exc.SADeprecationWarning)
 
-        self.addCleanup(warnings.resetwarnings)
+        self.addCleanup(self._reset_warning_filters)
+
+    def _reset_warning_filters(self):
+        warnings.filters[:] = self._original_warning_filters
